@@ -1,21 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# A python library to generate navigation menus using Telegram Bot API
-# Copyright (C) 2020
-# Armel MEVELLEC <mevellea@gmail.com>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser Public License for more details.
-#
-# You should have received a copy of the GNU Lesser Public License
-# along with this program.  If not, see [http://www.gnu.org/licenses/].
+#!/usr/bin/env python3
 # pylint: disable=too-many-arguments
 
 """Messages and navigation models."""
@@ -26,12 +9,11 @@ from abc import ABC, abstractmethod
 from enum import Enum, auto
 from typing import TYPE_CHECKING, Any, List, Optional, Union
 
-import emoji
 import telegram
 from telegram import InlineKeyboardMarkup, KeyboardButton, ReplyKeyboardMarkup
 
 if TYPE_CHECKING:
-    from telegram_menu import NavigationManager
+    from telegram_menu import NavigationHandler
 
 KeyboardContent = List[Union[str, List[str]]]
 
@@ -90,7 +72,7 @@ class BaseMessage(ABC):  # pylint: disable=too-many-instance-attributes
 
     def __init__(
         self,
-        navigation: "NavigationManager",
+        navigation: "NavigationHandler",
         label: str,
         expiry_period: Optional[datetime.timedelta] = None,
         inlined: bool = False,
@@ -121,6 +103,16 @@ class BaseMessage(ABC):  # pylint: disable=too-many-instance-attributes
 
         self._status = None
 
+    @abstractmethod
+    def update(self) -> str:
+        """Update message content.
+
+        Returns:
+            Message content formatted with markdown format.
+
+        """
+        raise NotImplementedError
+
     def get_button(self, label: str) -> Optional[MenuButton]:
         """Get button matching given label.
 
@@ -136,19 +128,6 @@ class BaseMessage(ABC):  # pylint: disable=too-many-instance-attributes
         """
         return next(iter(x for x in self.keyboard if x.label == label), None)
 
-    @staticmethod
-    def emojize(emoji_name: str) -> str:
-        """Get utf-16 code for emoji, defined in https://www.webfx.com/tools/emoji-cheat-sheet/.
-
-        Args:
-            emoji_name: emoji label
-
-        Returns:
-            emoji encoded as string
-
-        """
-        return emoji.emojize(f":{emoji_name}:", use_aliases=True)
-
     def add_button(self, label: str, callback: Any = None) -> None:
         """Add a button to keyboard attribute.
 
@@ -168,11 +147,6 @@ class BaseMessage(ABC):  # pylint: disable=too-many-instance-attributes
         """
         return self._navigation.edit_message(self)
 
-    @abstractmethod
-    def content_updater(self) -> str:
-        """Update message content."""
-        raise NotImplementedError
-
     def gen_keyboard_content(self, inlined: Optional[bool] = None) -> Union[ReplyKeyboardMarkup, InlineKeyboardMarkup]:
         """Generate keyboard.
 
@@ -240,26 +214,3 @@ class BaseMessage(ABC):  # pylint: disable=too-many-instance-attributes
     def kill_message(self) -> None:
         """Display status before message is destroyed."""
         self._logger.debug("Removing message '%s' (%s)", self.label, self.message_id)
-
-    @staticmethod
-    def format_list_to_html(args_array: KeyboardContent) -> str:
-        """Format array of strings in html, first element bold.
-
-        Args:
-            args_array: text content
-
-        """
-        content = ""
-        for line in args_array:
-            if isinstance(line, list):
-                if line[0] != "":
-                    content += f"<b>{line[0]}</b>"
-                    if line[1] != "":
-                        content += ": "
-                if line[1] != "":
-                    content += line[1]
-            else:
-                content += f"<b>{line}</b>"
-
-            content += "\n"
-        return content
